# Image_Encryption_Decryption 

This Software or package is used for Encrypting and Decrypting Images 
___

### How to use this application
___
**Follow this *steps* to use this application**
___

- Main requiremet is you must have *Python* and *pip* install
- If you Don't have python Don't worry follow this steps
- For Unix and Linux based Opreting systems
  - By deafult unix and linux users have python preinstall 
  - Just open Terminal and type
   - ``` python3```
   - Then install pip using apt for Debian Family
   -  ``` sudo apt install python3-pip```
   -  For RHEL Family 
   -  ``` sudo yum install python3-pip``` 
- For Windows 
    - For installetion of Python on windows [click hear](https://www.python.org/)
    - Now You Sucessecfully installed Python Don't worry Pip is install automaticaly.
- Then, we will move to installetion of Image-Encryption-Decryption Application.
- Use this commond for Unix/Linux distro's (**Terminal**)
- ```sh
   pip3 install image-enc-dec
  ```
- Use this commond for Windows Commond Prompt (**CMD**)
- ```py 
  import ImageEncDec
  ```
- Now You able to use this Project.
______
<<<<<<< HEAD


=======
>>>>>>> 8f54c370102c29198ba6160f0ecea91f5a3f6b80
## Snapshots
![Screenshot 2021-07-24 11:40:20](https://user-images.githubusercontent.com/50815912/126859412-cfc1260c-fb06-42a5-b9a4-c75880da54cc.png)
![Screenshot 2021-07-24 11:40:57](https://user-images.githubusercontent.com/50815912/126859420-ba395cca-e987-436e-8eaf-38f8dc1880b5.png)

<<<<<<< HEAD
=======

>>>>>>> 8f54c370102c29198ba6160f0ecea91f5a3f6b80
